@@ -20,6 +20,8 @@ from qtpy.QtWidgets import QMessageBox
 import nbformat
 
 # Spyder imports
+from spyder.api.config.mixins import SpyderConfigurationAccessor
+from spyder.utils.misc import get_python_executable
 from spyder.utils.programs import get_temp_dir
 from spyder.widgets.tabs import Tabs
 
@@ -40,10 +42,16 @@ WELCOME_DARK = osp.join(PACKAGE_PATH, 'utils', 'templates',
 # Filter to use in file dialogs
 FILES_FILTER = '{} (*.ipynb)'.format(_('Jupyter notebooks'))
 
+# How long to wait after save before checking whether file exists (in ms)
+WAIT_SAVE_DELAY = 250
+
+# How often to wait for that time
+WAIT_SAVE_ITERATIONS = 20
+
 logger = logging.getLogger(__name__)
 
 
-class NotebookTabWidget(Tabs):
+class NotebookTabWidget(Tabs, SpyderConfigurationAccessor):
     """
     Tabbed widget whose tabs display notebooks.
 
@@ -152,7 +160,9 @@ class NotebookTabWidget(Tabs):
 
         client = NotebookClient(self, filename, self.actions)
         self.add_tab(client)
-        server_info = self.server_manager.get_server(filename, start=True)
+        interpreter = self.get_interpreter()
+        server_info = self.server_manager.get_server(
+            filename, interpreter, start=True)
         if server_info:
             logger.debug('Using existing server at %s',
                          server_info['notebook_dir'])
@@ -160,6 +170,25 @@ class NotebookTabWidget(Tabs):
             client.load_notebook()
         return client
 
+    def get_interpreter(self):
+        """
+        Return the Python interpreter to be used in notebooks.
+
+        This function looks in the Spyder configuration to determine and
+        return the Python interpreter to be used in notebooks, which is the
+        same as is used in consoles.
+
+        Returns
+        -------
+        The file name of the interpreter
+        """
+        pyexec = self.get_conf(
+            option='executable',
+            section='main_interpreter',
+            default=get_python_executable()
+        )
+        return pyexec
+
     def maybe_create_welcome_client(self):
         """
         Create a welcome tab if there are no tabs.
@@ -246,17 +275,10 @@ class NotebookTabWidget(Tabs):
         filename = client.filename
         if not self.is_newly_created(client):
             return filename
-
-        # Read file to see whether notebook is empty
-        wait_save = QEventLoop()
-        QTimer.singleShot(1000, wait_save.quit)
-        wait_save.exec_()
-        nb_contents = nbformat.read(filename, as_version=4)
-        if (len(nb_contents['cells']) == 0
-                or len(nb_contents['cells'][0]['source']) == 0):
+        if self.wait_and_check_if_empty(filename):
             return filename
 
-        # Ask user to save notebook with new filename
+        # Notebook not empty, so ask user to save with new filename
         buttons = QMessageBox.Yes | QMessageBox.No
         text = _("<b>{0}</b> has been modified.<br>"
                  "Do you want to save changes?").format(osp.basename(filename))
@@ -267,6 +289,49 @@ class NotebookTabWidget(Tabs):
         else:
             return filename
 
+    @staticmethod
+    def wait_and_check_if_empty(filename):
+        """
+        Wait until notebook is created and check whether it is empty.
+
+        Repeatedly try to read the file, waiting a bit after every attempt.
+        At the first attempt where the file exists, test whether it is empty
+        and return. If it takes too long before the file is created, pretend
+        it is empty.
+
+        Parameters
+        ----------
+        filename : str
+            File name of notebook to be checked.
+
+        Returns
+        -------
+        True if notebook is empty or on timeout, False otherwise.
+        """
+        for iteration in range(WAIT_SAVE_ITERATIONS):
+
+            # Wait a bit
+            wait_save = QEventLoop()
+            QTimer.singleShot(WAIT_SAVE_DELAY, wait_save.quit)
+            wait_save.exec_()
+
+            # Try reading the file
+            try:
+                nb_contents = nbformat.read(filename, as_version=4)
+            except FileNotFoundError:
+                continue
+
+            # If empty, we are done
+            if (len(nb_contents['cells']) == 0
+                    or len(nb_contents['cells'][0]['source']) == 0):
+                return True
+            else:
+                return False
+        else:
+            # It is taking longer than expected;
+            # Just return True and hope for the best
+            return True
+
     def save_as(self, name=None, reopen_after_save=True):
         """
         Save current notebook under a different file name.
@@ -372,35 +437,47 @@ class NotebookTabWidget(Tabs):
         self.setCurrentIndex(index)
         self.setTabToolTip(index, widget.get_filename())
 
-    def handle_server_started(self):
+    def handle_server_started(self, process):
         """
         Handle signal that a notebook server has started.
 
         Go through all notebook tabs which do not have server info and try
-        getting the server info for them.
+        getting the server info for them. If that marches the server process
+        that has started, then update the notebook tab.
+
+        Parameters
+        ----------
+        process : ServerProcess
+            Info about the server that has started.
         """
+        pid = process.process.processId()
         for client_index in range(self.count()):
             client = self.widget(client_index)
             if not client.static and not client.server_url:
                 logger.debug('Getting server for %s', client.filename)
                 server_info = self.server_manager.get_server(
-                    client.filename, start=False)
-                if server_info:
+                    client.filename, process.interpreter, start=False)
+                if server_info and server_info['pid'] == pid:
                     logger.debug('Success')
                     client.register(server_info)
                     client.load_notebook()
 
-    def handle_server_timed_out_or_error(self):
-        """Display message box that server failed to start."""
+    def handle_server_timed_out_or_error(self, process):
+        """
+        Display message box that server failed to start.
+
+        Parameters
+        ----------
+        process : ServerProcess
+            Info about the server that failed to start.
+        """
         QMessageBox.critical(
             self,
             _("Server error"),
-            _("The Jupyter Notebook server failed to start or it is "
-              "taking too much time to do it. Please start it in a "
-              "system terminal with the command 'jupyter notebook' to "
-              "check for errors."))
-        # Create a welcome widget
-        # See issue 93
+            _("The Spyder Notebook server failed to start or it is "
+              "taking too much time to do it. Please select 'Server info' "
+              "in the plugin's option menu to check for errors."))
+        # Create a welcome widget, see gh:spyder-ide/spyder-notebook#93
         self.untitled_num -= 1
         self.maybe_create_welcome_client()
         return None
